@@ -658,9 +658,6 @@ class LuaBfbsGenerator : public BaseBfbsGenerator {
   void EmitCodeBlock(const std::string& code_block, const std::string& name,
                      const std::string& ns,
                      const std::string& declaring_file) const {
-    const std::string root_type = schema_->root_table()->name()->str();
-    const std::string root_file =
-        schema_->root_table()->declaration_file()->str();
     const std::string full_qualified_name = ns.empty() ? name : ns + "." + name;
 
     std::string code = "--[[ " + full_qualified_name + "\n\n";
@@ -672,7 +669,15 @@ class LuaBfbsGenerator : public BaseBfbsGenerator {
     code += "  flatc version: " + flatc_version_ + "\n";
     code += "\n";
     code += "  Declared by  : " + declaring_file + "\n";
-    code += "  Rooting type : " + root_type + " (" + root_file + ")\n";
+
+    const r::Object* root_table = schema_->root_table();
+    if (root_table) {
+      const std::string root_type = root_table->name()->str();
+      const std::string root_file = root_table->declaration_file()->str();
+
+      code += "  Rooting type : " + root_type + " (" + root_file + ")\n";
+    }
+
     code += "\n--]]\n\n";
 
     if (!requires_.empty()) {
@@ -698,7 +703,7 @@ class LuaBfbsGenerator : public BaseBfbsGenerator {
     EnsureDirExists(path);
     const std::string file_name =
         options_.output_path + path + "/" + namer_.File(name);
-    SaveFile(file_name.c_str(), code, false);
+    options_.file_saver->SaveFile(file_name.c_str(), code, false);
   }
 
   std::unordered_set<std::string> keywords_;
