@@ -47,7 +47,7 @@ struct NsDefinition {
   std::string path;
   std::string filepath;
   std::string symbolic_name;
-  const Namespace* ns;
+  const Namespace* ns = nullptr;
   std::map<std::string, const Definition*> definitions;
 };
 
@@ -118,7 +118,6 @@ class TsGenerator : public BaseGenerator {
     if (!parser_.opts.ts_omit_entrypoint) {
       generateEntry();
     }
-    if (!generateBundle()) return false;
     return true;
   }
 
@@ -178,7 +177,7 @@ class TsGenerator : public BaseGenerator {
     EnsureDirExists(dirs);
     auto basename = dirs + namer_.File(definition, SkipFile::Suffix);
 
-    return SaveFile(basename.c_str(), code, false);
+    return parser_.opts.file_saver->SaveFile(basename.c_str(), code, false);
   }
 
   void TrackNsDef(const Definition& definition, std::string type_name) {
@@ -258,7 +257,7 @@ class TsGenerator : public BaseGenerator {
       nsDef.path = root;
       nsDef.symbolic_name = file_name_;
       nsDef.filepath = path_ + file_name_ + ".ts";
-      nsDef.ns = new Namespace();
+      nsDef.ns = parser_.empty_namespace_;
       ns_defs_[nsDef.path] = nsDef;
     }
 
@@ -319,33 +318,12 @@ class TsGenerator : public BaseGenerator {
         export_counter++;
       }
 
-      if (export_counter > 0) SaveFile(it.second.filepath.c_str(), code, false);
+      if (export_counter > 0)
+        parser_.opts.file_saver->SaveFile(it.second.filepath.c_str(), code,
+                                          false);
     }
   }
 
-  bool generateBundle() {
-    if (parser_.opts.ts_flat_files) {
-      std::string inputpath;
-      std::string symbolic_name = file_name_;
-      inputpath = path_ + file_name_ + ".ts";
-      std::string bundlepath =
-          GeneratedFileName(path_, file_name_, parser_.opts);
-      bundlepath = bundlepath.substr(0, bundlepath.size() - 3) + ".js";
-      std::string cmd = "esbuild";
-      cmd += " ";
-      cmd += inputpath;
-      // cmd += " --minify";
-      cmd += " --format=cjs --bundle --outfile=";
-      cmd += bundlepath;
-      cmd += " --external:flatbuffers";
-      std::cout << "Entry point " << inputpath << " generated." << std::endl;
-      std::cout << "A single file bundle can be created using fx. esbuild with:"
-                << std::endl;
-      std::cout << "> " << cmd << std::endl;
-    }
-    return true;
-  }
-
   // Generate a documentation comment, if available.
   static void GenDocComment(const std::vector<std::string>& dc,
                             std::string* code_ptr,
@@ -360,7 +338,12 @@ class TsGenerator : public BaseGenerator {
     code += "/**\n";
     for (auto it = dc.begin(); it != dc.end(); ++it) {
       if (indent) code += indent;
-      code += " *" + *it + "\n";
+      std::string safe = *it;
+      for (size_t pos = 0; (pos = safe.find("*/", pos)) != std::string::npos;) {
+        safe.replace(pos, 2, "*\\/");
+        pos += 3;
+      }
+      code += " *" + safe + "\n";
     }
     if (indent) code += indent;
     code += " */\n";
@@ -497,8 +480,12 @@ class TsGenerator : public BaseGenerator {
             std::string enum_name =
                 AddImport(imports, *value.type.enum_def, *value.type.enum_def)
                     .name;
-            std::string enum_value = namer_.Variant(
-                *value.type.enum_def->FindByValue(value.constant));
+            const EnumVal* val =
+                value.type.enum_def->FindByValue(value.constant);
+            if (val == nullptr) {
+              val = value.type.enum_def->MinValue();
+            }
+            std::string enum_value = namer_.Variant(*val);
             ret += enum_name + "." + enum_value +
                    (i < value.type.fixed_length - 1 ? ", " : "");
           }
@@ -513,9 +500,10 @@ class TsGenerator : public BaseGenerator {
           return "BigInt('" + value.constant + "')";
         }
         default: {
-          EnumVal* val = value.type.enum_def->FindByValue(value.constant);
-          if (val == nullptr)
-            val = const_cast<EnumVal*>(value.type.enum_def->MinValue());
+          const EnumVal* val = value.type.enum_def->FindByValue(value.constant);
+          if (val == nullptr) {
+            val = value.type.enum_def->MinValue();
+          }
           return AddImport(imports, *value.type.enum_def, *value.type.enum_def)
                      .name +
                  "." + namer_.Variant(*val);
